==> apache-storm-1.2.4-src.tar.gz: apache-storm-1.2.4/external/storm-cassandra/src/main/java/org/apache/storm/cassandra/executor/impl/SingleAsyncResultHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.storm.cassandra.executor.impl;

import org.apache.storm.task.OutputCollector;
import org.apache.storm.tuple.Tuple;
import org.apache.storm.cassandra.ExecutionResultHandler;
import org.apache.storm.cassandra.executor.AsyncResultHandler;
import org.apache.storm.cassandra.executor.ExecutionResultCollector;

import java.util.concurrent.ConcurrentLinkedQueue;


public class SingleAsyncResultHandler implements AsyncResultHandler<Tuple> {

    private ConcurrentLinkedQueue<ExecutionResultCollector> completed;

    private ExecutionResultHandler handler;

    /**
     * Creates a new {@link SingleAsyncResultHandler} instance.
     * @param handler
     */
    public SingleAsyncResultHandler(ExecutionResultHandler handler) {
        this.handler = handler;
        this.completed = new ConcurrentLinkedQueue<>();
    }

    /**
     * This method is responsible for failing specified inputs.
     *
     * The default method does no-operation.
     */
    public void failure(Throwable t, Tuple input) {
        completed.offer(new ExecutionResultCollector.FailedCollector(input, t));
    }
    /**
     * This method is responsible for acknowledging specified inputs.
     *
     * The default method does no-operation.
     */
    public void success(Tuple input) {
        completed.offer(new ExecutionResultCollector.SucceedCollector(input));
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void flush(final OutputCollector collector) {
        ExecutionResultCollector poll;
        while( (poll = completed.poll()) != null ) {
            poll.handle(collector, handler);
        }
    }
}

==> apache-storm-2.3.0-src.tar.gz: apache-storm-2.3.0/external/storm-cassandra/src/main/java/org/apache/storm/cassandra/executor/impl/SingleAsyncResultHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The ASF licenses this file to you under the Apache License, Version
 * 2.0 (the "License"); you may not use this file except in compliance with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the specific language governing permissions
 * and limitations under the License.
 */

package org.apache.storm.cassandra.executor.impl;

import java.util.concurrent.ConcurrentLinkedQueue;
import org.apache.storm.cassandra.ExecutionResultHandler;
import org.apache.storm.cassandra.executor.AsyncResultHandler;
import org.apache.storm.cassandra.executor.ExecutionResultCollector;
import org.apache.storm.task.OutputCollector;
import org.apache.storm.tuple.Tuple;

public class SingleAsyncResultHandler implements AsyncResultHandler<Tuple> {

    private ConcurrentLinkedQueue<ExecutionResultCollector> completed;

    private ExecutionResultHandler handler;

    /**
     * Creates a new {@link SingleAsyncResultHandler} instance.
     */
    public SingleAsyncResultHandler(ExecutionResultHandler handler) {
        this.handler = handler;
        this.completed = new ConcurrentLinkedQueue<>();
    }

    /**
     * This method is responsible for failing specified inputs.
     *
     * <p>The default method does no-operation.
     */
    @Override
    public void failure(Throwable t, Tuple input) {
        completed.offer(new ExecutionResultCollector.FailedCollector(input, t));
    }

    /**
     * This method is responsible for acknowledging specified inputs.
     *
     * <p>The default method does no-operation.
     */
    @Override
    public void success(Tuple input) {
        completed.offer(new ExecutionResultCollector.SucceedCollector(input));
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void flush(final OutputCollector collector) {
        ExecutionResultCollector poll;
        while ((poll = completed.poll()) != null) {
            poll.handle(collector, handler);
        }
    }
}
